==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/TemplateColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateCellUpdatingEventArgsDescriptionMetadata } from "./TemplateCellUpdatingEventArgsDescriptionMetadata";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { TemplateColumnDescription } from "./TemplateColumnDescription";
/**
 * @hidden
 */
var TemplateColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TemplateColumnDescriptionMetadata, _super);
    function TemplateColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateColumnDescriptionMetadata.e = function (a) {
        a.item("TemplateRef", "(w:Template,wf:Template,xam:Template)DataRef:String");
    };
    TemplateColumnDescriptionMetadata.b = function (a) {
        if (TemplateColumnDescriptionMetadata.a == null) {
            TemplateColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateColumnDescriptionMetadata.c(TemplateColumnDescriptionMetadata.a);
        }
        if (a.j(TemplateColumnDescriptionMetadata.a)) {
            return;
        }
        a.y(TemplateColumnDescriptionMetadata.a);
        TemplateCellUpdatingEventArgsDescriptionMetadata.d(a);
    };
    TemplateColumnDescriptionMetadata.c = function (a) {
        DataGridColumnDescriptionMetadata.c(a);
        a.item("CellUpdatingRef", "EventRef::cellUpdating");
        TemplateColumnDescriptionMetadata.e(a);
    };
    TemplateColumnDescriptionMetadata.d = function (a) {
        TemplateColumnDescriptionMetadata.b(a);
        a.aa("TemplateColumn", function () { return new TemplateColumnDescription(); });
        a.z("TemplateColumn", TemplateColumnDescriptionMetadata.a);
    };
    TemplateColumnDescriptionMetadata.$t = markType(TemplateColumnDescriptionMetadata, 'TemplateColumnDescriptionMetadata');
    TemplateColumnDescriptionMetadata.a = null;
    return TemplateColumnDescriptionMetadata;
}(Base));
export { TemplateColumnDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/TemplateColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateCellUpdatingEventArgsDescriptionMetadata } from "./TemplateCellUpdatingEventArgsDescriptionMetadata";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { TemplateColumnDescription } from "./TemplateColumnDescription";
/**
 * @hidden
 */
var TemplateColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TemplateColumnDescriptionMetadata, _super);
    function TemplateColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateColumnDescriptionMetadata.e = function (a) {
        a.item("TemplateRef", "(w:Template,wf:Template,xam:Template)DataRef:String");
    };
    TemplateColumnDescriptionMetadata.b = function (a) {
        if (TemplateColumnDescriptionMetadata.a == null) {
            TemplateColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateColumnDescriptionMetadata.c(TemplateColumnDescriptionMetadata.a);
        }
        if (a.k(TemplateColumnDescriptionMetadata.a)) {
            return;
        }
        a.aa(TemplateColumnDescriptionMetadata.a);
        TemplateCellUpdatingEventArgsDescriptionMetadata.d(a);
    };
    TemplateColumnDescriptionMetadata.c = function (a) {
        DataGridColumnDescriptionMetadata.c(a);
        a.item("CellUpdatingRef", "EventRef::cellUpdating");
        TemplateColumnDescriptionMetadata.e(a);
    };
    TemplateColumnDescriptionMetadata.d = function (a) {
        TemplateColumnDescriptionMetadata.b(a);
        a.ac("TemplateColumn", function () { return new TemplateColumnDescription(); });
        a.ab("TemplateColumn", TemplateColumnDescriptionMetadata.a);
    };
    TemplateColumnDescriptionMetadata.$t = markType(TemplateColumnDescriptionMetadata, 'TemplateColumnDescriptionMetadata');
    TemplateColumnDescriptionMetadata.a = null;
    return TemplateColumnDescriptionMetadata;
}(Base));
export { TemplateColumnDescriptionMetadata };
